.. image:: https://img.shields.io/travis/danjac/pyramid_storage.svg
        :target: https://travis-ci.org/danjac/pyramid_storage

.. image:: https://img.shields.io/pypi/v/pyramid_storage.svg
        :target: https://pypi.python.org/pypi/pyramid_storage


**pyramid_storage** is a package for handling file uploads in your Pyramid framework application.

Official docs:

https://pythonhosted.org/pyramid_storage/

Tested with python 3.7. 3.8, 3.9, 3.10, and 3.11

This package was inspired by the flask-uploads package:

https://github.com/srusskih/flask-uploads
